## Overview
Handy utilities mainly for computer vision


## Installation
```
git clone https://github.com/quarrying/khandy.git
cd khandy
pip install -e .
```


## Dependencies
One of the principles of this project is to ensure minimal dependencies.

- Python 3.5+
- NumPy 1.11+
- OpenCV 2.0+
- Pillow
- lxml
- requests

